import argparse
from . import decapitator

# at the module level, we'll have to make our own parser


def build_module_argparser():
    parser = argparse.ArgumentParser()

    subparsers = parser.add_subparsers()

    parser_decapitator = subparsers.add_parser('decapitator')
    decapitator.add_args_to_parser(parser_decapitator)
    parser_decapitator.set_defaults(func=decapitator.main)

    subparsers.required = True
    subparsers.dest = "command"

    return parser


def main():
    args = build_module_argparser().parse_args()
    args.func(args)


if __name__ == "__main__":
    main()



#!/usr/bin/env python3

# I totally stole this off the internet from the reddit bot
# Gonna rewrite it when I get a second cause I don't like it as it is

# Inputs must be at least 5 characters and start and end with the same letter


import argparse
import sys

filler = '/'


def cubify(word, subsqaures=True):
    # if not ((word.__len__() >= 5) & (word.isalpha()) & (word.endswith(word[0]))):
    if not ((word.__len__() >= 5) & (word.endswith(word[0]))):

        sys.exit(word + " cannot be cubified.")

    word = word.upper()

    # create matrix filled with placeholder .
    size = int(word.__len__() / 2 + word.__len__()) + 1
    matrix = [[' ' for x in range(size)] for y in range(size)]

    gap = int(len(word) / 2)

    correction = 0
    if ((len(word) % 2) == 0):
        correction = 1

    for i in range(len(word)):
        # write horizontal words
        matrix[0][gap + i] = word[i]
        matrix[gap][i] = word[i]
        matrix[2*gap - correction][gap + i] = word[i]
        matrix[3*gap - correction][i] = word[i]

        # write vertical words
        matrix[gap + i][0] = word[i]
        matrix[i][gap] = word[i]
        matrix[i][3*gap - correction] = word[i]
        matrix[gap + i][2*gap - correction] = word[i]

    # write diagonal
    for i in range(1,gap):
        matrix[gap - i][i] = filler
        matrix[gap - i][2 * gap + i - correction] = filler
        matrix[3 * gap - i - correction][i] = filler
        matrix[3 * gap - i - correction][2 * gap + i - correction] = filler

    if(subsqaures):
        # add subsquare
        # determine at which position subsquare has to be added
        amountOfSubsqaures = 0
        if (len(word) < 12):
            amountOfSubsqaures = int(int(len(word) / 2) / 4)
        else:
            amountOfSubsqaures = int(int(len(word) / 2) / 3) - 1

        positionOfSubsquares = [int(int(len(word)/2)/(amountOfSubsqaures+1)) * (x+1) for x in range(amountOfSubsqaures)]

        # actual code of add subsquare
        for position in positionOfSubsquares:
            for i in range(len(word)):
                # write horizontal words
                matrix[position][gap - position + i] = word[i]
                matrix[2*gap + position - correction][gap - position + i] = word[i]

                # write vertical words
                matrix[i + position][gap - position] = word[i]
                matrix[i + position][3*gap - position - correction] = word[i]

    # making matrix pretty
    # matrix = [[x if x != ' ' else ' ' for x in row] for row in matrix]     #replace background with another character
    matrix = [' '.join(row) for row in matrix]

    matrix = ['    ' + row for row in matrix]

    return displayMatrix(matrix)


def displayMatrix(matrix):
    """Makes a multilined string"""
    string = ''
    for x in matrix:
        for y in x:
            string += y
        string += '\n'
    return string


def add_args_to_parser(parser):
    parser.add_argument('input_string', help='the string to decap')

    return parser


def build_parser_standalone():
    parser = argparse.ArgumentParser(description="cubify a string")
    return add_args_to_parser(parser)


def main(args):
    print(cubify(args.input_string))


if __name__ == "__main__":
    args = build_parser_standalone().parse_args()
    main(args)



#!/usr/bin/env python3

import argparse


def add_args_to_parser(parser):
    parser.add_argument('input_string', help='the string to decap')

    return parser


def build_parser_standalone():
    parser = argparse.ArgumentParser(description="decap")
    return add_args_to_parser(parser)


def main(args):

    decapitated_string = ""
    index = 0

    for c in args.input_string:
        if index % 2 == 0:
            decapitated_string += c.upper()
        else:
            decapitated_string += c.lower()
        index += 1

    print(decapitated_string)


if __name__ == "__main__":
    args = build_parser_standalone().parse_args()
    main(args)



#!/usr/bin/env python3

import argparse


def add_args_to_parser(parser):
    parser.add_argument("text")
    return parser


def build_parser_standalone():
    parser = argparse.ArgumentParser(description="square")
    return add_args_to_parser(parser)


def main(args):
    text = args.text.upper().split()
    out = " ".join([c for s in text for c in s]) + '\n'
    for i in range(1,max([len(s) for s in text])):
        for s in text:
            try:
                out += s[i]
            except:
                out += ' '
            try:
                out += ' '*(len(s)-1)*2
            except:
                pass
            out += ' '
        else:
            out = out[0:-1] + '\n'
    else:
        out = out[0:-1]
    print(out)


if __name__ == "__main__":
    args = build_parser_standalone().parse_args()
    main(args)




import argparse
from . import decapitator
from . import squares
from . import rot13
from . import cubify


def build_parsers():
    parser = argparse.ArgumentParser()
    subparsers = parser.add_subparsers(dest="command_name")
    subparsers.required = True

    parser.add_argument('--version', help="output m3m3s' version and halt.",
                        action='version',
                        version=f"m3m3s {__version__}")

    parser_decap = subparsers.add_parser('decap')
    decapitator.add_args_to_parser(parser_decap)
    parser_decap.set_defaults(func=decapitator.main)

    parser_squares = subparsers.add_parser('squares')
    squares.add_args_to_parser(parser_squares)
    parser_squares.set_defaults(func=squares.main)

    parser_rot13 = subparsers.add_parser('rot13')
    rot13.add_args_to_parser(parser_rot13)
    parser_rot13.set_defaults(func=rot13.main)

    parser_cubify = subparsers.add_parser('cubify')
    cubify.add_args_to_parser(parser_cubify)
    parser_cubify.set_defaults(func=cubify.main)

    return parser


def main():
    parser = build_parsers()
    args = parser.parse_args()
    if hasattr(args, 'func'):
        args.func(args)

from ._version import get_versions
__version__ = get_versions()['version']
del get_versions



#!/usr/bin/env python3


# usage EITHER
# ./rot13.py hello world
# echo hello world | ./rot13.py
# echo hello world | ./rot13.py | ./rot13.py # :D
# (command line "args" take presedence over stdin)

# good ole rot 13 encryption.
# I prefer the `tr "A-Z" "N-ZA-M"` version for the command line
# but wanted to mess with making a python "pipe" that could work with the system

# Also, I should write some "real" code to get my tshirt :D

# I thought about using the argparse thing from the decap script but wanted to try something different
# this means that I can't take any arguments in if I ever wanted to in the future...

import argparse


def add_args_to_parser(parser):
    parser.add_argument('input_string', help='the string to rot13')

    return parser


def build_parser_standalone():
    parser = argparse.ArgumentParser(description="rot13")
    return add_args_to_parser(parser)


ENCRYPTDICT = {}

normal = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
encrypted = "nopqrstuvwxyzabcdefghijklmNOPQRSTUVWXYZABCDEFGHIJKLM"

ENCRYPTDICT = {plain: cipher for plain, cipher in zip(normal, encrypted)}


def encrypt(x):
    if x in ENCRYPTDICT:
        return ENCRYPTDICT[x]
    else:
        return x


def main(args):
    unencryptedString = args.input_string
    encryptedString = "".join([encrypt(x) for x in unencryptedString])

    print(encryptedString)


if __name__ == "__main__":
    args = build_parser_standalone().parse_args()
    main(args)



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
# thanks to https://blog.ionelmc.ro/2014/05/25/python-packaging/#the-structure for this template
from __future__ import absolute_import
from __future__ import print_function

import io
import versioneer

from glob import glob
from os.path import basename
from os.path import dirname
from os.path import join
from os.path import splitext

from setuptools import find_packages
from setuptools import setup


def read(*names, **kwargs):
    return io.open(
        join(dirname(__file__), *names),
        encoding=kwargs.get('encoding', 'utf8')
    ).read()


setup(
    name='m3m3s',
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    license='MIT License',
    description='Scripts for memes',
    # long_description='%s\n' % (
    #     re.compile('^.. start-badges.*^.. end-badges', re.M | re.S).sub('', read('README.md')),
    #     # re.sub(':[a-z]+:`~?(.*?)`', r'``\1``', read('CHANGELOG.rst'))
    # ),
    author='Jake Fenton',
    author_email='jake@fenton.io',
    url='https://github.com/rileyannis/memescripts',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    py_modules=[splitext(basename(path))[0] for path in glob('src/*.py')],
    include_package_data=True,
    zip_safe=False,
    classifiers=[
        # complete classifier list: http://pypi.python.org/pypi?%3Aaction=list_classifiers
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: Unix',
        'Operating System :: POSIX',
        # 'Operating System :: Microsoft :: Windows',
        # 'Programming Language :: Python',
        # 'Programming Language :: Python :: 2.7',
        # 'Programming Language :: Python :: 3',
        # 'Programming Language :: Python :: 3.3',
        # 'Programming Language :: Python :: 3.4',
        # 'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        # 'Programming Language :: Python :: Implementation :: CPython',
        # 'Programming Language :: Python :: Implementation :: PyPy',
        # uncomment if you test on these interpreters:
        # 'Programming Language :: Python :: Implementation :: IronPython',
        # 'Programming Language :: Python :: Implementation :: Jython',
        # 'Programming Language :: Python :: Implementation :: Stackless',
        'Topic :: Utilities',
    ],
    keywords=[
        # eg: 'keyword1', 'keyword2', 'keyword3',
    ],
    install_requires=[
        'versioneer',
        'wheel',
        # eg: 'aspectlib==1.1.1', 'six>=1.7',
    ],
    extras_require={
    },
    entry_points={
        'console_scripts': [
            'm3m3s = m3m3s:main',
        ]
    },
)
